summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2015-02-07 08:56:08 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2015-02-07 09:07:09 -0600
commitb6c9ac630429b8aa71edd59e13e19029927aeef6 (patch)
treefe3d073215e0c50292e6d50c68bc53fe8c60572b
parent8cd78da8b3e087349cd21933b439fcede2e33fd3 (diff)
downloadlibpng-b6c9ac630429b8aa71edd59e13e19029927aeef6.tar.gz
[libpng16] Imported from libpng-1.6.17beta02.tarv1.6.17beta02
-rw-r--r--LICENSE4
-rw-r--r--README2
-rw-r--r--libpng-manual.txt15
-rw-r--r--libpng.323
-rw-r--r--libpngpf.32
-rw-r--r--png.52
-rw-r--r--png.h10
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt2
-rw-r--r--scripts/pnglibconf.h.prebuilt2
11 files changed, 34 insertions, 32 deletions
diff --git a/LICENSE b/LICENSE
index a8dc909e6..8c94602f8 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.6.17beta02, January 29, 2015, are
+libpng versions 1.2.6, August 15, 2004, through 1.6.17beta02, February 7, 2015, are
Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-January 29, 2015
+February 7, 2015
diff --git a/README b/README
index 7b6e9fda3..bb7bcaab0 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.6.17beta02 - January 29, 2015 (shared library 16.0)
+README for libpng version 1.6.17beta02 - February 7, 2015 (shared library 16.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
diff --git a/libpng-manual.txt b/libpng-manual.txt
index c1748a010..48ecfc0c5 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.6.17beta02 - January 29, 2015
+ libpng version 1.6.17beta02 - February 7, 2015
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.6.17beta02 - January 29, 2015
+ libpng versions 0.97, January 1998, through 1.6.17beta02 - February 7, 2015
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -344,22 +344,23 @@ then only check the bytes (if any) that your program didn't read.
to replace them with custom functions. See the discussion under
Customizing libpng.
-
FILE *fp = fopen(file_name, "rb");
if (!fp)
{
return (ERROR);
}
- fread(header, 1, number, fp);
- is_png = !png_sig_cmp(header, 0, number);
+ if (fread(header, 1, number, fp) != number)
+ {
+ return (ERROR);
+ }
+ is_png = !png_sig_cmp(header, 0, number);
if (!is_png)
{
return (NOT_PNG);
}
-
Next, png_struct and png_info need to be allocated and initialized. In
order to ensure that the size of these structures is correct even with a
dynamically linked libpng, there are functions to initialize and
@@ -5274,7 +5275,7 @@ Other rules can be inferred by inspecting the libpng source.
XVI. Y2K Compliance in libpng
-January 29, 2015
+February 7, 2015
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
diff --git a/libpng.3 b/libpng.3
index 5113479db..4eac76877 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,4 +1,4 @@
-.TH LIBPNG 3 "January 29, 2015"
+.TH LIBPNG 3 "February 7, 2015"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.6.17beta02
.SH SYNOPSIS
@@ -504,7 +504,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.6.17beta02 - January 29, 2015
+ libpng version 1.6.17beta02 - February 7, 2015
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -515,7 +515,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.6.17beta02 - January 29, 2015
+ libpng versions 0.97, January 1998, through 1.6.17beta02 - February 7, 2015
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -848,22 +848,23 @@ then only check the bytes (if any) that your program didn't read.
to replace them with custom functions. See the discussion under
Customizing libpng.
-
FILE *fp = fopen(file_name, "rb");
if (!fp)
{
return (ERROR);
}
- fread(header, 1, number, fp);
- is_png = !png_sig_cmp(header, 0, number);
+ if (fread(header, 1, number, fp) != number)
+ {
+ return (ERROR);
+ }
+ is_png = !png_sig_cmp(header, 0, number);
if (!is_png)
{
return (NOT_PNG);
}
-
Next, png_struct and png_info need to be allocated and initialized. In
order to ensure that the size of these structures is correct even with a
dynamically linked libpng, there are functions to initialize and
@@ -5778,7 +5779,7 @@ Other rules can be inferred by inspecting the libpng source.
.SH XVI. Y2K Compliance in libpng
-January 29, 2015
+February 7, 2015
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
@@ -6093,7 +6094,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.6.17beta02 - January 29, 2015:
+Libpng version 1.6.17beta02 - February 7, 2015:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -6116,7 +6117,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.6.17beta02, January 29, 2015, are
+libpng versions 1.2.6, August 15, 2004, through 1.6.17beta02, February 7, 2015, are
Copyright (c) 2004,2006-2014 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -6215,7 +6216,7 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-January 29, 2015
+February 7, 2015
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index 14ca6ed27..8d2397f1e 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "January 29, 2015"
+.TH LIBPNGPF 3 "February 7, 2015"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.6.17beta02
(private functions)
diff --git a/png.5 b/png.5
index 4ffa7134f..cee4e45d4 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "January 29, 2015"
+.TH PNG 5 "February 7, 2015"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index 1ab7597ac..847e90208 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.6.17beta02 - January 29, 2015
+libpng version 1.6.17beta02 - February 7, 2015
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 1a3cf6cee..a7686b004 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source
*
- * libpng version 1.6.17beta02 - January 29, 2015
+ * libpng version 1.6.17beta02 - February 7, 2015
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index 395f1f789..bb3448a4a 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,5 +1,5 @@
-Makefiles for libpng version 1.6.17beta02 - January 29, 2015
+Makefiles for libpng version 1.6.17beta02 - February 7, 2015
pnglibconf.h.prebuilt => Stores configuration settings
makefile.linux => Linux/ELF makefile
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 0366ff36e..0a9112a76 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -2,7 +2,7 @@
/* pnglibconf.h - library build configuration */
-/* Libpng version 1.6.17beta02 - January 29, 2015 */
+/* Libpng version 1.6.17beta02 - February 7, 2015 */
/* Copyright (c) 1998-2014 Glenn Randers-Pehrson */
diff --git a/png.h b/png.h
index 0eb876ae8..a1b777d67 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.6.17beta02, January 29, 2015
* Copyright (c) 1998-2015 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.6.17beta02, January 29, 2015: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -244,7 +244,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.6.17beta02, January 29, 2015, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -356,7 +356,7 @@
* Y2K compliance in libpng:
* =========================
*
- * January 29, 2015
+ * February 7, 2015
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
@@ -426,7 +426,7 @@
/* Version information for png.h - this should match the version in png.c */
#define PNG_LIBPNG_VER_STRING "1.6.17beta02"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.6.17beta02 - January 29, 2015\n"
+ " libpng version 1.6.17beta02 - February 7, 2015\n"
#define PNG_LIBPNG_VER_SONUM 16
#define PNG_LIBPNG_VER_DLLNUM 16
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.6.17beta02, January 29, 2015
+ * libpng version 1.6.17beta02, February 7, 2015
* Copyright (c) 1998-2015 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.6.17beta02, January 29, 2015: Glenn
+ * libpng versions 0.97, January 1998, through 1.6.17beta02, February 7, 2015: Glenn
* See also "Contributing Authors", below.
*
@@ -244,7 +244,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.6.17beta02, January 29, 2015, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.6.17beta02, February 7, 2015, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5